/*
 * @Author: 祝玲云
 * @Date: 2021-06-25 14:01:20
 * @LastEditTime: 2021-06-25 14:01:20
 * @LastEditors: Please set LastEditors
 * @Description: 插件统一入口
 * @FilePath: \xs-plugins\src\lib\index.js
 */

const path = require('path')
const RouterPlugins = require('./router')
const ApiPlugins = require('./api')
const MenuPlugin = require('./menu')
const fs = require('fs');

// 自动生成插件默认配置项
const plugins = {
    autoPath: 'src/automatically',  // 文件生成位置
    entry: '', // 遍历文件夹的位置
}

class IndexPlugins {
    constructor(options) {
        plugins.entry = path.join('/src/modules/' + options.moduleConfig.CUR_MODULES + '/')
        this.options = options
    }
    // 自动化插件统一入口
    async apply (compiler) {
        if(process.env.NODE_ENV === 'development') {
            this.getOptions(compiler)
        } else {
            // 删除自动生成文件
            this.delDir(path.join(this.options.rootPath, '/' + plugins.autoPath))
            compiler.plugin('run', async (compilation, callback) => { 
                await this.getOptions (compiler)
                callback()
            })
        }
    }
    async getOptions (compiler){
        let router = new RouterPlugins({...plugins, ...this.options}).apply(compiler)
        let api = await new ApiPlugins({...plugins, ...this.options}).apply(compiler)
        await new MenuPlugin({...plugins, ...this.options, router, api}).apply(compiler)
    }
    delDir (path){
        let files = [];
        if(fs.existsSync(path)){
            files = fs.readdirSync(path);
            files.forEach((file, index) => {
                let curPath = path + "/" + file;
                if(fs.statSync(curPath).isDirectory()){
                    this.delDir(curPath); //递归删除文件夹
                } else {
                    fs.unlinkSync(curPath); //删除文件
                }
            });
            fs.rmdirSync(path);
        }
    }
}

module.exports = IndexPlugins